#!/bin/bash

# Exit on error
set -e

# Exit on unbound variable
#set -u

# Print all commands
#set -x

function showUsage {
    echo "usage: $0 [-f] -k key_file -i input_file -o output_file"
    echo "    -f first upload to Google Web Store"
    echo "    -k private key file"
    echo "    -i extension input zip file"
    echo "    -o extension output zip file"
}

### Check parameters
firstUpload=""
while getopts ':k:i:o:f' OPTION ; do
  case "$OPTION" in
    k) keyFile=$OPTARG;;
    i) inputZipFile=$OPTARG;;
    o) outputZipFile=$OPTARG;;
    f) firstUpload=true;;
    *) showUsage;;
  esac
done

if [ -z "$keyFile" -o -z "$inputZipFile" -o -z "$outputZipFile" ]
then
    showUsage
    exit 1
fi

if [ ! -e "$keyFile" ]
then
    echo "Key file not found"
    showUsage
    exit 1
fi

if [ ! -e "$inputZipFile" ]
then
    echo "Extension input zip file file not found"
    showUsage
    exit 1
fi


### Extract extension zip file
tempDir=$(mktemp -d)
unzip -q "$inputZipFile" -d "$tempDir/"


### Let the user update some settings
name=$(sed -n -r 's/^\s*"name":\s*"(.+)".*$/\1/p'               "$tempDir/manifest.json")
read -e -p "Please enter the name of extension: " -i "$name" name

description=$(sed -n -r 's/^\s*"description":\s*"(.+)".*$/\1/p' "$tempDir/manifest.json")
read -e -p "Please enter the description of extension: " -i "$description" description

author=$(sed -n -r 's/^\s*"author":\s*"(.+)".*$/\1/p'           "$tempDir/manifest.json")
read -e -p "Please enter the author of extension: " -i "$author" author


### Update manifest
sed -i -e "s/\(\"name\"\:\s*\)\".*\"/\1\"$name\"/" "$tempDir/manifest.json"
sed -i -e "s/\(\"description\"\:\s*\)\".*\"/\1\"$description\"/" "$tempDir/manifest.json"
sed -i -e "s/\(\"author\"\:\s*\)\".*\"/\1\"$author\"/" "$tempDir/manifest.json"


# Prepare first upload
if [ -n "$firstUpload" ]
then
    echo "Rebuilding extension for INITIAL UPLOAD to Google Web Store"

    # Remove key definition in manifest
    sed -i -e '/"key"/d' "$tempDir/manifest.json"

    # Add key file to extension
    cp "$keyFile" "$tempDir/key.pem"
else
    # Update public key in manifest
    publicKey=$(./showPublicKey.sh "$keyFile")
    sed -i -e "s~\(\"key\"\:\s*\)\".*\"~\1\"$publicKey\"~" "$tempDir/manifest.json"    
fi


### Build result zip file
echo "Creating zip file to upload:   $outputZipFile"
rm -f "$outputZipFile"
zip -j -q -r "$outputZipFile" "$tempDir"


### Build result crx file
outputCrxFile=${outputZipFile%%.*}.crx
echo "Creating crx file for hosting: $outputCrxFile"
./makecrx.sh "$tempDir" "$keyFile" "$outputCrxFile"



